@@ -109,7 +109,8 @@ func (cfg *PackerConfig) EvalContext(ctx BlockContext, variables map[string]cty.
 			}),
 			buildAccessor: cty.UnknownVal(cty.EmptyObject),
 			packerAccessor: cty.ObjectVal(map[string]cty.Value{
-				"version": cty.StringVal(cfg.CorePackerVersionString),
+				"version":     cty.StringVal(cfg.CorePackerVersionString),
+				"iterationID": cty.UnknownVal(cty.String),
 			}),
 			pathVariablesAccessor: cty.ObjectVal(map[string]cty.Value{
 				"cwd":  cty.StringVal(strings.ReplaceAll(cfg.Cwd, `\`, `/`)),
@@ -118,6 +119,14 @@ func (cfg *PackerConfig) EvalContext(ctx BlockContext, variables map[string]cty.
 		},
 	}
 
+	// Store the iteration_id, if it exists. Otherwise, it'll be "unknown"
+	if cfg.bucket != nil {
+		ectx.Variables[packerAccessor] = cty.ObjectVal(map[string]cty.Value{
+			"version":     cty.StringVal(cfg.CorePackerVersionString),
+			"iterationID": cty.StringVal(cfg.bucket.Iteration.ID),
+		})
+	}
+
 	// In the future we'd like to load and execute HCL blocks using a graph
 	// dependency tree, so that any block can use any block whatever the
 	// order.
